<?php declare(strict_types = 1);

namespace Drupal\billwerk_subscriptions;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;

/**
 * Helper manager class for interact with the Billwerk related Drupal roles.
 */
final class BillwerkRolesManager {

  /**
	 * The settings config.
	 * @var ImmutableConfig
	 */
	protected ImmutableConfig $config;

  /**
   * Constructs a BillwerkRolesManager object.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
  ) {
    $this->config = $configFactory->get('billwerk_subscriptions.settings');
  }


  /**
   * Returns the Billwerk handled Role ID's as array from the settings.
   *
   * We're not returning role objects, as Drupal does it the same way.
   *
   * @return array
   */
  public function getBillwerkRoles(): array {
    // Also set the values as keys to make sure it's unique and easier to
    // interact with.
    return array_flip($this->config->get('billwerk_roles'));
  }

}
